%define _hardened_build 1

Name:           bitcoin
Version:        24.0
Release:        1%{?dist}
Summary:        A peer-to-peer electronic crypto-currency cash system
License:        MIT
URL:            http://bitcoin.org/
Source0:        https://github.com/bitcoin/bitcoin/archive/v%{version}.tar.gz

BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  boost-devel
BuildRequires:  coreutils
BuildRequires:  db4-devel
BuildRequires:  desktop-file-utils
BuildRequires:  diffutils
BuildRequires:  gcc-c++
BuildRequires:  gettext
BuildRequires:  java
BuildRequires:  krb5-devel
BuildRequires:  libdb4-cxx-devel
BuildRequires:  libevent-devel
BuildRequires:  libtool
BuildRequires:  miniupnpc-devel
BuildRequires:  openssl-devel
BuildRequires:  protobuf-compiler
BuildRequires:  protobuf-devel
BuildRequires:  python
BuildRequires:  qrencode-devel
BuildRequires:  qt5-linguist
BuildRequires:  qt5-qtbase-devel
BuildRequires:  qt-devel
BuildRequires:  util-linux
BuildRequires:  zlib-devel
%if 0%{?fedora} >= 20
BuildRequires:  boost-system
%endif

Requires:       desktop-file-utils

# Check for existence of LibreSSL is broken, remove it
# We don't actually build with LibreSSL
Patch2: bitcoin-0.11.1-broken-libressl-check.patch


%package devel
Summary:  Header files and libraries needed for bitcoin development
Provides: bitcoin-devel = %{version}-%{release}
Provides: bitcoin-libs  = %{version}-%{release}
Requires: bitcoin       = %{version}-%{release}

%description devel
Header files and libraries for bitcoin development

%description
Bitcoin is a free open source peer-to-peer electronic cash system that is
completely decentralized, without the need for a central server or trusted
parties. Users hold the crypto keys to their own money and transact directly
with each other, with the help of a P2P network to check for double-spending.

See the documentation at the bitcoin wiki:
  https://en.bitcoin.it/wiki/Main_Page
for help and more information.

This is the standard-client bitcoin-core.

%prep
%setup -q -n bitcoin-%{version}

%build
./autogen.sh

%configure
make %{?_smp_mflags}

%install
%makeinstall

mkdir -p -m 755 %{buildroot}%{_sbindir}
mv %{buildroot}%{_bindir}/bitcoind %{buildroot}%{_sbindir}/bitcoind

%{__install} -m 644 -D -p src/qt/res/src/bitcoin.svg %{buildroot}%{_datadir}/icons/hicolor/scalable/apps/bitcoin.svg

mkdir -p %{buildroot}%{_datadir}/applications
cat <<EOF > %{buildroot}%{_datadir}/applications/bitcoin-core.desktop
[Desktop Entry]
Encoding=UTF-8
Name=Bitcoin
Comment=Bitcoin P2P Cryptocurrency
Comment[fr]=Bitcoin, monnaie virtuelle cryptographique pair à pair
Comment[tr]=Bitcoin, eşten eşe kriptografik sanal para birimi
Exec=bitcoin-qt %u
Terminal=false
Type=Application
Icon=bitcoin128
MimeType=x-scheme-handler/bitcoin;
Categories=Office;Finance;
EOF
# change touch date when modifying desktop
touch -a -m -t 201511100546 %{buildroot}%{_datadir}/applications/bitcoin-core.desktop
%{_bindir}/desktop-file-validate %{buildroot}%{_datadir}/applications/bitcoin-core.desktop

gzip %{buildroot}%{_mandir}/man1/*.1

rm -f %{buildroot}%{_libdir}/libbitcoinconsensus.{la,a}

mkdir -p $RPM_BUILD_ROOT/%{_sysconfdir}/bash_completion.d/
install -m644 contrib/bitcoin-cli.bash-completion  $RPM_BUILD_ROOT/%{_sysconfdir}/bash_completion.d/bitcoin-cli
install -m644 contrib/bitcoin-tx.bash-completion  $RPM_BUILD_ROOT/%{_sysconfdir}/bash_completion.d/bitcoin-tx
install -m644 contrib/bitcoind.bash-completion  $RPM_BUILD_ROOT/%{_sysconfdir}/bash_completion.d/bitcoind

#%check
#make check
#pushd src
#srcdir=. test/bitcoin-util-test.py
#popd
#qa/pull-tester/rpc-tests.py -extended

%post
touch --no-create %{_datadir}/icons/hicolor &>/dev/null || :
update-desktop-database &> /dev/null || :

%postun
if [ $1 -eq 0 ] ; then
    touch --no-create %{_datadir}/icons/hicolor &>/dev/null
    gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :
fi
update-desktop-database &> /dev/null || :

%posttrans
gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :

%post devel -p /sbin/ldconfig

%postun devel -p /sbin/ldconfig

%files
%defattr(-,root,root,0755)
%doc COPYING README.md 
%{_bindir}/*
%{_sbindir}/*
%{_mandir}/man1/*
%{_datadir}/applications/bitcoin-core.desktop
%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg
%{_sysconfdir}/bash_completion.d/bitcoin-cli
%{_sysconfdir}/bash_completion.d/bitcoin-tx
%{_sysconfdir}/bash_completion.d/bitcoind

%files devel
%defattr(-,root,root,-)
%{_libdir}/lib*.so
%{_libdir}/lib*.so.*
%{_includedir}/bitcoinconsensus.h
%{_libdir}/pkgconfig/*.pc

%changelog
* Tue Nov 29 2022 josef radinger <cheese@nosuchhost.net> - 24.0-1
- bump version

* Fri Apr 29 2022 josef radinger <cheese@nosuchhost.net> - 23.0-1
- bump version

* Thu Sep 16 2021 josef radinger <cheese@nosuchhost.net> - 22.0-1
- bump version

* Thu May 13 2021 josef radinger <cheese@nosuchhost.net> - 0.21.1-1
- bump version

* Sat Jan 16 2021 josef radinger <cheese@nosuchhost.net> - 0.21.0-1
- bump version

* Fri Nov 13 2020 josef radinger <cheese@nosuchhost.net> - 0.20.1-3
- rebuild for fedora 33
- cleanup specfile
- remove configure parameters

* Sun Aug 02 2020 josef radinger <cheese@nosuchhost.net> - 0.20.1-1
- bump version

* Thu Jun 04 2020 josef radinger <cheese@nosuchhost.net> - 0.20.0-1
- bump version

* Thu Mar 05 2020 josef radinger <cheese@nosuchhost.net> - 0.19.1-1
- bump version

* Wed Nov 20 2019 josef radinger <cheese@nosuchhost.net> - 0.19.0.1-1
- bump version

* Sun Nov 10 2019 josef radinger <cheese@nosuchhost.net> - 0.19.0-1
- bump version

* Sat Aug 03 2019 josef radinger <cheese@nosuchhost.net> - 0.18.1-1
- bump version
- a little bit of spec-file cleanup

* Thu May 02 2019 josef radinger <cheese@nosuchhost.net> - 0.18.0-1
- bump version

* Sun Dec 23 2018 josef radinger <cheese@nosuchhost.net> - 0.17.1-1
- bump version

* Sat Oct 27 2018 josef radinger <cheese@nosuchhost.net> - 0.17.0.1-1
- bump version

* Tue Oct 02 2018 josef radinger <cheese@nosuchhost.net> - 0.17.0-1
- bump version
- no longer use debian's desktop-file
- no longer use debians examples

* Thu Sep 20 2018 josef radinger <cheese@nosuchhost.net> - 0.16.3-1
- bump version

* Mon Jul 30 2018 josef radinger <cheese@nosuchhost.net> - 0.16.2-1
- bump version

* Thu Jun 14 2018 josef radinger <cheese@nosuchhost.net> - 0.16.1-1
- bump version

* Thu May 03 2018 josef radinger <cheese@nosuchhost.net> - 0.16.0-2
- change buildrequires: mktemp -> coreutils

* Thu Mar 01 2018 josef radinger <cheese@nosuchhost.net> - 0.16.0-1
- bump version

* Fri Nov 10 2017 josef radinger <cheese@nosuchhost.net> - 0.15.1-1
- bump version
- remove patch2 from sources
- remove README.Fedora

* Sun Sep 17 2017 josef radinger <cheese@nosuchhost.net> - 0.15.0.1-1
- bump version

* Tue Sep 12 2017 josef radinger <cheese@nosuchhost.net> - 0.15.0-1
- bump version

* Thu Jun 15 2017 josef radinger <cheese@nosuchhost.net> - 0.14.2-1
- bump version

* Sat Apr 22 2017 josef radinger <cheese@nosuchhost.net> - 0.14.1-1
- bump version

* Tue Mar 07 2017 josef radinger <cheese@nosuchhost.net> - 0.14.0-1
- bump version
- no longer install man-pages manually
- install bash-completion

* Tue Jan 03 2017 josef radinger <cheese@nosuchhost.net> - 0.13.2-1
- bump version

* Fri Oct 28 2016 josef radinger <cheese@nosuchhost.net> - 0.13.1-1
- bump version

* Mon Aug 22 2016 josef radinger <cheese@nosuchhost.net> - 0.13.0-1
- bump version

* Tue Jul 12 2016 josef radinger <cheese@nosuchhost.net> - 0.12.1-2
- rebuild for newer miniupnpc

* Sun Apr 17 2016 josef radinger <cheese@nosuchhost.net> - 0.12.1-1
- bump version

* Sat Feb 20 2016 josef radinger <cheese@nosuchhost.net> - 0.12.0-1
- bump version
- remove patch1
- remove patch2
- add BuildRequires on libevent-devel
- qa/pull-tester/rpc-tests.py instead of qa/pull-tester/rpc-tests.sh
- remove fundrawtransaction.py from checks
- add BuildRequires on qt5-qtbase-devel and qt5-linguist
- disable check

* Thu Feb 04 2016 josef radinger <cheese@nosuchhost.net> - 0.11.2-4
- remove static openssl
- enable hardened build
- remove dependency on git, perl, sed
- add BuildRequires on miniupnpc-devel, java, python

* Fri Jan 29 2016 josef radinger <cheese@nosuchhost.net> - 0.11.2-3
- new openssl
- enable check
- add no-dso for openssl

* Tue Dec 15 2015 josef radinger <cheese@nosuchhost.net> - 0.11.2-2
- new openssl

* Fri Nov 13 2015 josef radinger <cheese@nosuchhost.net> - 0.11.2-1
- bump version

* Thu Oct 15 2015 josef radinger <cheese@nosuchhost.net> - 0.11.1-1
- bump version
- cleanup cxxflags
- add pkconfig-files to -devel-package

* Sun Jul 12 2015 josef radinger <cheese@nosuchhost.net> - 0.11.0-1
- bump version

* Fri Jul 10 2015 josef radinger <cheese@nosuchhost.net> - 0.10.2-3
- bump openssl to 1.0.2d

* Sat Jun 13 2015 josef radinger <cheese@nosuchhost.net> - 0.10.2-2
- bump openssl to 1.0.2c

* Sun May 24 2015 josef radinger <cheese@nosuchhost.net> - 0.10.2-1
- bump version
- bump openssl

* Wed Apr 29 2015 josef radinger <cheese@nosuchhost.net> - 0.10.1-1
- bump version
- bump openssl

* Fri Feb 13 2015 josef radinger <cheese@nosuchhost.net> - 0.10.0-1
- bump version
- bump openssl
- add BuildRequires on libtool
- add BuildRequires on qrencode
- split devel-package and library

* Sun Oct 26 2014 josef radinger <cheese@nosuchhost.net> - 0.9.3-1
- bump version of bitcoin
- new openssl

* Wed Jul 02 2014 josef radinger <cheese@nosuchhost.net> - 0.9.2.1-2
- and fix ssl :)
- we use our own version again

* Sat Jun 21 2014 josef radinger <cheese@nosuchhost.net> - 0.9.2.1-1
- fedora supports ec, we no longer ship our own openssl
- remove --enable-cli, --enable-daemon, --enable-gui from configure-cmdline
- remove README.fedora
- bump version

* Sat Jun 14 2014 josef radinger <cheese@nosuchhost.net> - 0.9.2-1
- bump version
- cleanup specfile

* Thu Apr 10 2014 josef radinger <cheese@nosuchhost.net> - 0.9.1-2
- new openssl

* Thu Apr 10 2014 josef radinger <cheese@nosuchhost.net> - 0.9.1-1
- bump version

* Tue Apr 08 2014 josef radinger <cheese@nosuchhost.net> - 0.9.0-3
- update openssl

* Sat Mar 29 2014 josef radinger <cheese@nosuchhost.net> - 0.9.0-2
- further cleanup spec-file
- update openssl to 1.0.1f
- enable ipv6

* Sat Mar 22 2014 josef radinger <cheese@nosuchhost.net> - 0.9.0-1
- bump version
- new buildsystem
- protobuf-devel
- clean spec-file

* Sat Jan 18 2014 josef radinger <cheese@nosuchhost.net> - 0.8.6-3
- disable -mt for fedora20 onwards

* Tue Dec 17 2013 josef radinger <cheese@nosuchhost.net> - 0.8.6-2
- fix icon

* Sat Dec 14 2013 josef radinger <cheese@nosuchhost.net> - 0.8.6-1
- bump version

* Fri Sep 27 2013 josef radinger <cheese@nosuchhost.net> - 0.8.5-1
- bump version

* Thu Sep 05 2013 josef radinger <cheese@nosuchhost.net> - 0.8.4-1
- bump version
- add BuildRequires protobuf-compiler

* Sat Jul 06 2013 josef radinger <cheese@nosuchhost.net> - 0.8.3-1
- bump version

* Sun Jun 2 2013 josef radinger <cheese@nosuchhost.net> - 0.8.2-1
- bump version
- move bitcoind from libexec to bin

* Fri Mar 22 2013 josef radinger <cheese@nosuchhost.net> - 0.8.1-1
- bump version

* Sun Feb 24 2013 josef radinger <cheese@nosuchhost.net> - 0.8.0-1
- bump version
- bump version of openssl to 1.0.1e

* Sun Jan 27 2013 josef radinger <cheese@nosuchhost.net> - 0.7.2-2
- rebuild

* Sun Dec 30 2012 josef radinger <cheese@nosuchhost.net> - 0.7.2-1
- bump version

* Sun Oct 21 2012 josef radinger <cheese@nosuchhost.net> - 0.7.1-1
- bump version
- some cleanup of specfile

* Tue Sep 18 2012 josef radinger <cheese@nosuchhost.net> - 0.7.0-2
- conditional fc18-build

* Tue Sep 18 2012 josef radinger <cheese@nosuchhost.net> - 0.7.0-1
- bump version

* Sun Jul 01 2012 josef radinger <cheese@nosuchhost.net> - 0.6.3-2
- modify buildrequires for openssl

* Sat Jun 30 2012 josef radinger <cheese@nosuchhost.net> - 0.6.3-1
- bump version openssl
- bump version bitcoin

* Thu May 17 2012 josef radinger <cheese@nosuchhost.net> - 0.6.2.2-1
- bump version
- mangle spec-file
- download sources and package them, as the "standard" 
  download leads to unversioned builds

* Mon May 07 2012 josef radinger <cheese@nosuchhost.net> - 0.6.1-3
- try to fix openssl-paths

* Mon May 07 2012 josef radinger <cheese@nosuchhost.net> - 0.6.1-2
- full release

* Thu May 03 2012 josef radinger <cheese@nosuchhost.net> - 0.6.1rc2-1
- bump version for bitcoin

* Thu May 03 2012 josef radinger <cheese@nosuchhost.net> - 0.6.0-3
- bump openssl to 1.0.1b

* Thu May 03 2012 josef radinger <cheese@nosuchhost.net> - 0.6.0-2
- recompile, no problems in mock

* Wed Apr 4 2012 <ismael@olea.org> - 0.6.0-1
- updated to 0.6.0*
- deprecated makefile.fedora
- deprecated packager bitcoin-qt.pro
- upgraded to openssl-1.0.0g

* Wed Dec 7 2011 <ismael@olea.org> - 0.5.0-1
- first release

